@@ -4,21 +4,17 @@ Created on Tue Jun  9 14:33:49 2020
 
 @author: svc_ccg
 """
+from __future__ import annotations
 
 import datetime
-import enum
 import glob
 import json
 import os
 import pathlib
-import subprocess
-import sys  # , shutil
-from typing import Optional, Union
 
 import psycopg2
 import psycopg2.extras
 
-
 if __name__ == "__main__":
     ...
 else:
@@ -34,7 +30,7 @@ class MultipleBehaviorSessionsError(Exception):
 
 
 def get_foraging_id_from_behavior_session(
-    mouse_id: Union[int, str], start: datetime.datetime, end: datetime.datetime
+    mouse_id: int | str, start: datetime.datetime, end: datetime.datetime
 ) -> str:
     fmt = "%Y-%m-%d %H:%M"
     query = f"""
@@ -389,7 +385,7 @@ class lims_data_getter(data_getter):
 
         self.probe_data = probe_data
 
-    def storage_directory(self) -> Optional[str]:
+    def storage_directory(self) -> str | None:
         """Get the storage directory for this experiment"""
         if self.data_dict:
             return "/" + self.data_dict["storage_directory"]
